.. MESMER-OpenSCM Runner documentation master file, created by
   sphinx-quickstart on Wed Dec 22 11:31:42 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MESMER-OpenSCM Runner's documentation!
=================================================

.. toctree::
   :maxdepth: 2
   :caption: Documentation:

   installation

.. include:: ../../README.rst
    :start-after: sec-begin-title
    :end-before: sec-end-title

.. include:: ../../README.rst
    :start-after: sec-begin-shortsummary
    :end-before: sec-end-shortsummary

.. include:: ../../README.rst
    :start-after: sec-begin-citing
    :end-before: sec-end-citing

.. include:: ../../README.rst
    :start-after: sec-begin-license
    :end-before: sec-end-license

.. toctree::
   :maxdepth: 2
   :caption: API reference:

   mesmer_openscmrunner.draw_realisations
